@@ -6,10 +6,7 @@
  * See the included LICENSE file for more details.
  */
 
-global.expect = require("chai").expect
-
-var portCounter = 9042
-global.nextPort = function() {
-  return ++portCounter
+let portCounter = 9042
+module.exports.nextPort = () => {
+    return ++portCounter
 }
-
